#!/bin/sh
#####################################################################
#Written by Paul Stothard
#
#stothard@ualberta.ca
#
#space_check.sh
#--------------
#This shell script monitors hard drive space and sends an email when
#space becomes scarce. On the first day of each month the script sends
#an email report of hard drive space.
#
#Note, if sendmail fails, try adding 'sendmail: 127.0.0.1' to
#/etc/hosts.allow
#
#Script set-up
#-------------
#1. Edit some of the variables in space_check.sh so that they are suitable
#for your system. In particular you may want to modify the values of
#COMPUTER, SENDMAIL, MAILTO, and THRESHOLD.
#
#2. To run the script use ./space_check.sh as root. Alternatively,
#place this script in /etc/cron.daily/, or create a link to the script
#in /etc/cron.daily/.
#

wd=`pwd`

#Settings section:
#####################################################################
#Edit variables below:
#Name for computer. This name is used when creating the backup
#filenames.
COMPUTER=my_computer

#Path to sendmail.
SENDMAIL=/usr/sbin/sendmail

#Person to receive email reports.
MAILTO='someaddress@someplace.com'

#Send email if disk space use is above this percentage for any
#filesystem
THRESHOLD=90

#Path to df
DF=/bin/df

#Path to perl
PERL=/usr/bin/perl

#####################################################################

#Date of the Month e.g. 27
DOM=`date +%d`

#Full date e.g. 2006_09_02
FULLDATE=`date +%Y_%m_%d`

#Change DOW text to lowercase
DOW=`echo $DOW | tr A-Z a-z`

function check_execution {
    exit_status="$1"
    command="$2"
    if [ $exit_status -ne 0 ]; then
	echo "space_check.sh failed with command $command"
	email "space_check.sh" "Script failed with command $command"
	exit "$exit_status"
    fi
}

function email {
    subject="$1"
    message="$2"

echo "From: $COMPUTER
To: $MAILTO
Subject: $subject
Mime-Version: 1.0
Content-Type: text/plain" > /tmp/message$$

    echo -e "$message" >> /tmp/message$$
    $SENDMAIL -t -oi < /tmp/message$$
    exit_status=$?
    if [ $exit_status -ne 0 ]; then
	echo "Unable to send email using $SENDMAIL"
	exit "$exit_status"
    fi
}

#Create df report
$DF -lhP > /tmp/report$$
check_execution $? "$DF -lhP > /tmp/report$$"

contents=`cat /tmp/report$$`

if [ $DOM = "01" ] ; then
    contents=`cat /tmp/report$$`
    email "Hard drive space report" "The hard drive space on $COMPUTER on ${FULLDATE}:\n$contents\n"

else
    #Determine whether threshold is exceeded
    threshold_exceeded=`perl -w -e 'open(DATA, "<" . $ARGV[0]); while (<DATA>) {if($_ =~ m/(\d+)\%/) {if ($1 >= $ARGV[1]) {print "1"; exit 0;} } } close(DATA); print "0";' /tmp/report$$ $THRESHOLD`
    if [ $threshold_exceeded = "1" ] ; then
	email "Hard drive space running out" "The hard drive space on $COMPUTER on ${FULLDATE}:\n$contents\n"
    fi
fi

cd "$wd"
exit 0

